@@ -13,6 +13,10 @@
 #include "utils/tuplesort.h"
 #include "vector.h"
 
+#if PG_VERSION_NUM >= 160000
+#include "varatt.h"
+#endif
+
 #if PG_VERSION_NUM >= 150000
 #include "common/pg_prng.h"
 #endif
@@ -21,6 +25,10 @@
 #include "portability/instr_time.h"
 #endif
 
+#if PG_VERSION_NUM >= 190000
+typedef Pointer Item;
+#endif
+
 #define IVFFLAT_MAX_DIM 2000
 
 /* Support functions */
