@@ -5,18 +5,27 @@
 
 #include "catalog/pg_type.h"
 #include "common/shortest_dec.h"
-#include "common/string.h"
 #include "fmgr.h"
 #include "halfutils.h"
 #include "halfvec.h"
+#include "lib/stringinfo.h"
 #include "libpq/pqformat.h"
 #include "sparsevec.h"
 #include "utils/array.h"
 #include "utils/builtins.h"
 #include "utils/float.h"
+#include "utils/fmgrprotos.h"
 #include "utils/lsyscache.h"
 #include "vector.h"
 
+#if PG_VERSION_NUM >= 160000
+#include "varatt.h"
+#endif
+
+#if PG_VERSION_NUM >= 170000
+#include "parser/scansup.h"
+#endif
+
 typedef struct SparseInputElement
 {
 	int32		index;
@@ -150,9 +159,9 @@ InitSparseVector(int dim, int nnz)
 	return result;
 }
 
-/*
- * Check for whitespace, since array_isspace() is static
- */
+#if PG_VERSION_NUM >= 170000
+#define sparsevec_isspace(ch) scanner_isspace(ch)
+#else
 static inline bool
 sparsevec_isspace(char ch)
 {
@@ -165,6 +174,7 @@ sparsevec_isspace(char ch)
 		return true;
 	return false;
 }
+#endif
 
 /*
  * Compare indices
