@@ -16,16 +16,20 @@
 #include "port.h"				/* for strtof() */
 #include "sparsevec.h"
 #include "utils/array.h"
-#include "utils/builtins.h"
 #include "utils/float.h"
+#include "utils/fmgrprotos.h"
 #include "utils/lsyscache.h"
-#include "utils/numeric.h"
+#include "utils/varbit.h"
 #include "vector.h"
 
 #if PG_VERSION_NUM >= 160000
 #include "varatt.h"
 #endif
 
+#if PG_VERSION_NUM >= 170000
+#include "parser/scansup.h"
+#endif
+
 #define STATE_DIMS(x) (ARR_DIMS(x)[0] - 1)
 #define CreateStateDatums(dim) palloc(sizeof(Datum) * (dim + 1))
 
@@ -36,7 +40,7 @@
 #endif
 
 #if PG_VERSION_NUM >= 180000
-PG_MODULE_MAGIC_EXT(.name = "vector",.version = "0.8.1");
+PG_MODULE_MAGIC_EXT(.name = "vector",.version = "0.8.2");
 #else
 PG_MODULE_MAGIC;
 #endif
@@ -129,9 +133,9 @@ InitVector(int dim)
 	return result;
 }
 
-/*
- * Check for whitespace, since array_isspace() is static
- */
+#if PG_VERSION_NUM >= 170000
+#define vector_isspace(ch) scanner_isspace(ch)
+#else
 static inline bool
 vector_isspace(char ch)
 {
@@ -144,6 +148,7 @@ vector_isspace(char ch)
 		return true;
 	return false;
 }
+#endif
 
 /*
  * Check state array
